==> estateplat-common-1.2.3-20180212.010915-29-sources.jar: cn/gtmap/estateplat/model/exchange/national/DjfDjSf.java <==
package cn.gtmap.estateplat.model.exchange.national;

import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbDoubleAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Id;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 登记收费
 * Created by xhc on 2015/11/20.
 */
@XmlRootElement(name = "DJF_DJ_SF")
public class DjfDjSf implements Serializable, AccessData {
    final static String ysdm = "6004040000";//要素代码
    @Id
    private String sfxmid;//主键
    private String ywh;//业务号
    private String jfry;//计费人员
    private Date jfrq;//计费日期
    private String sfkmmc;//收费科目名称
    private String sfewsf;//是否额外收费
    private String sfjs;//收费基数
    private String sflx;//收费类型
    private Double ysje;//应收金额
    private Double zkhysje;//折扣后应收金额
    private String sfry;//收费人员
    private Date sfrq;//收费日期
    private String fff;//付费方
    private String sjffr;//实际付费人
    private Double ssje;//实收金额
    private String sfdw;//收费单位
    private String qxdm;//区县代码
    private String yffr;//应付费人
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    /**
     * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
     * @description 数量
     */
    private Double sl;

    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 付费方式
     */
    private String fffs;

    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 缴费业务号
     */
    private String jfywh;
    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 付费人微信标示
     */
    private String ffrwxbs;

    /**
     * @author <a href="mailto:xuchao@gtmap.cn">xc</a>
     * @description 付费终端
     */
    private String ffzd;
    /**
     * @author <a href="mailto:xuchao@gtmap.cn">xc</a>
     * @description 缴费状态 1:未缴费，2：已开票未缴费，3：已缴费
     */
    private String jfzt;
    @XmlTransient
    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "JFRY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getJfry() {
        return jfry;
    }

    public void setJfry(String jfry) {
        this.jfry = jfry;
    }

    @XmlAttribute(name = "JFRQ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    @XmlAttribute(name = "SFKMMC")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSfkmmc() {
        return sfkmmc;
    }

    public void setSfkmmc(String sfkmmc) {
        this.sfkmmc = sfkmmc;
    }

    @XmlAttribute(name = "SFEWSF")
    public String getSfewsf() {
        return sfewsf;
    }

    public void setSfewsf(String sfewsf) {
        this.sfewsf = sfewsf;
    }

    @XmlAttribute(name = "SFJS")
    public String getSfjs() {
        return sfjs;
    }

    public void setSfjs(String sfjs) {
        this.sfjs = sfjs;
    }

    @XmlAttribute(name = "SFLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSflx() {
        return sflx;
    }

    public void setSflx(String sflx) {
        this.sflx = sflx;
    }

    @XmlAttribute(name = "YSJE")
    @XmlJavaTypeAdapter(JaxbDoubleAdapter.class)
    public Double getYsje() {
        return ysje;
    }

    public void setYsje(Double ysje) {
        this.ysje = ysje;
    }

    @XmlAttribute(name = "ZKHYSJE")
    public Double getZkhysje() {
        return zkhysje;
    }

    public void setZkhysje(Double zkhysje) {
        this.zkhysje = zkhysje;
    }

    @XmlAttribute(name = "SFRY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSfry() {
        return sfry;
    }

    public void setSfry(String sfry) {
        this.sfry = sfry;
    }

    @XmlAttribute(name = "SFRQ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getSfrq() {
        return sfrq;
    }

    public void setSfrq(Date sfrq) {
        this.sfrq = sfrq;
    }

    @XmlAttribute(name = "FFF")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getFff() {
        return fff;
    }

    public void setFff(String fff) {
        this.fff = fff;
    }

    @XmlAttribute(name = "SJFFR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSjffr() {
        return sjffr;
    }

    public void setSjffr(String sjffr) {
        this.sjffr = sjffr;
    }

    @XmlAttribute(name = "SSJE")
    @XmlJavaTypeAdapter(JaxbDoubleAdapter.class)
    public Double getSsje() {
        return ssje;
    }

    public void setSsje(Double ssje) {
        this.ssje = ssje;
    }

    @XmlAttribute(name = "SFDW")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSfdw() {
        return sfdw;
    }

    public void setSfdw(String sfdw) {
        this.sfdw = sfdw;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
    @XmlTransient
    public String getFffs() {
        return fffs;
    }

    public void setFffs(String fffs) {
        this.fffs = fffs;
    }

    @XmlTransient
    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    @XmlTransient
    public String getFfrwxbs() {
        return ffrwxbs;
    }

    public void setFfrwxbs(String ffrwxbs) {
        this.ffrwxbs = ffrwxbs;
    }

    @XmlTransient
    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    @XmlTransient
    public String getFfzd() {
        return ffzd;
    }

    public void setFfzd(String ffzd) {
        this.ffzd = ffzd;
    }
    @XmlTransient
    public String getYffr() {
        return yffr;
    }

    public void setYffr(String yffr) {
        this.yffr = yffr;
    }
    @XmlTransient
    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }
}

==> estateplat-common-1.2.3-20180505.051656-75-sources.jar: cn/gtmap/estateplat/model/exchange/national/DjfDjSf.java <==
package cn.gtmap.estateplat.model.exchange.national;

import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbDoubleAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Id;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 登记收费
 * Created by xhc on 2015/11/20.
 */
@XmlRootElement(name = "DJF_DJ_SF")
public class DjfDjSf implements Serializable, AccessData {
    final static String ysdm = "6004040000";//要素代码
    @Id
    private String sfxmid;//主键
    private String ywh;//业务号
    private String jfry;//计费人员
    private Date jfrq;//计费日期
    private String sfkmmc;//收费科目名称
    private String sfewsf;//是否额外收费
    private String sfjs;//收费基数
    private String sflx;//收费类型
    private Double ysje;//应收金额
    private Double zkhysje;//折扣后应收金额
    private String sfry;//收费人员
    private Date sfrq;//收费日期
    private String fff;//付费方
    private String sjffr;//实际付费人
    private Double ssje;//实收金额
    private String sfdw;//收费单位
    private String qxdm;//区县代码
    private String yffr;//应付费人
    private String cztxmbh;//财政条形码编号
    private String hjck;//核价窗口
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    /**
     * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
     * @description 数量
     */
    private Double sl;

    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 付费方式
     */
    private String fffs;

    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 缴费业务号
     */
    private String jfywh;
    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 付费人微信标示
     */
    private String ffrwxbs;

    /**
     * @author <a href="mailto:xuchao@gtmap.cn">xc</a>
     * @description 付费终端
     */
    private String ffzd;
    /**
     * @author <a href="mailto:xuchao@gtmap.cn">xc</a>
     * @description 缴费状态 1:未缴费，2：已开票未缴费，3：已缴费
     */
    private String jfzt;
    @XmlTransient
    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "JFRY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getJfry() {
        return jfry;
    }

    public void setJfry(String jfry) {
        this.jfry = jfry;
    }

    @XmlAttribute(name = "JFRQ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    @XmlAttribute(name = "SFKMMC")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSfkmmc() {
        return sfkmmc;
    }

    public void setSfkmmc(String sfkmmc) {
        this.sfkmmc = sfkmmc;
    }

    @XmlAttribute(name = "SFEWSF")
    public String getSfewsf() {
        return sfewsf;
    }

    public void setSfewsf(String sfewsf) {
        this.sfewsf = sfewsf;
    }

    @XmlAttribute(name = "SFJS")
    public String getSfjs() {
        return sfjs;
    }

    public void setSfjs(String sfjs) {
        this.sfjs = sfjs;
    }

    @XmlAttribute(name = "SFLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSflx() {
        return sflx;
    }

    public void setSflx(String sflx) {
        this.sflx = sflx;
    }

    @XmlAttribute(name = "YSJE")
    @XmlJavaTypeAdapter(JaxbDoubleAdapter.class)
    public Double getYsje() {
        return ysje;
    }

    public void setYsje(Double ysje) {
        this.ysje = ysje;
    }

    @XmlAttribute(name = "ZKHYSJE")
    public Double getZkhysje() {
        return zkhysje;
    }

    public void setZkhysje(Double zkhysje) {
        this.zkhysje = zkhysje;
    }

    @XmlAttribute(name = "SFRY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSfry() {
        return sfry;
    }

    public void setSfry(String sfry) {
        this.sfry = sfry;
    }

    @XmlAttribute(name = "SFRQ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getSfrq() {
        return sfrq;
    }

    public void setSfrq(Date sfrq) {
        this.sfrq = sfrq;
    }

    @XmlAttribute(name = "FFF")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getFff() {
        return fff;
    }

    public void setFff(String fff) {
        this.fff = fff;
    }

    @XmlAttribute(name = "SJFFR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSjffr() {
        return sjffr;
    }

    public void setSjffr(String sjffr) {
        this.sjffr = sjffr;
    }

    @XmlAttribute(name = "SSJE")
    @XmlJavaTypeAdapter(JaxbDoubleAdapter.class)
    public Double getSsje() {
        return ssje;
    }

    public void setSsje(Double ssje) {
        this.ssje = ssje;
    }

    @XmlAttribute(name = "SFDW")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getSfdw() {
        return sfdw;
    }

    public void setSfdw(String sfdw) {
        this.sfdw = sfdw;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
    @XmlTransient
    public String getFffs() {
        return fffs;
    }

    public void setFffs(String fffs) {
        this.fffs = fffs;
    }

    @XmlTransient
    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    @XmlTransient
    public String getFfrwxbs() {
        return ffrwxbs;
    }

    public void setFfrwxbs(String ffrwxbs) {
        this.ffrwxbs = ffrwxbs;
    }

    @XmlTransient
    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    @XmlTransient
    public String getFfzd() {
        return ffzd;
    }

    public void setFfzd(String ffzd) {
        this.ffzd = ffzd;
    }
    @XmlTransient
    public String getYffr() {
        return yffr;
    }

    public void setYffr(String yffr) {
        this.yffr = yffr;
    }
    @XmlTransient
    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    @XmlTransient
    public String getCztxmbh() {
        return cztxmbh;
    }

    public void setCztxmbh(String cztxmbh) {
        this.cztxmbh = cztxmbh;
    }

    @XmlTransient
    public String getHjck() {
        return hjck;
    }

    public void setHjck(String hjck) {
        this.hjck = hjck;
    }
}
